package org.archiviststoolkit.plugin;

import javax.naming.AuthenticationException;
import javax.naming.Context;
import javax.naming.NamingException;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;
import java.util.HashMap;
import java.util.Hashtable;

/**
 * Archivists' Toolkit(TM) Copyright � 2005-2010 Regents of the University of California, New York University, & Five Colleges, Inc.
 * All rights reserved.
 * <p/>
 * This software is free. You can redistribute it and / or modify it under the terms of the Educational Community License (ECL)
 * version 1.0 (http://www.opensource.org/licenses/ecl1.php)
 * <p/>
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the ECL license for more details about permissions and limitations.
 * <p/>
 * <p/>
 * Archivists' Toolkit(TM)
 * http://www.archiviststoolkit.org
 * info@archiviststoolkit.org
 * <p/>
 * Created by IntelliJ IDEA.
 *
 * Class that attempts to authenticate the user using a ldap server
 *
 * @author: Nathan Stevens
 * Date: Dec 9, 2010
 * Time: 11:48:45 AM
 */
public class LDAPAuthenticator {
    // holds the configuration data
    private HashMap<String, String> configData = null;

    // The message indicating with connecting to ldap server succeeded or failed
    private String message = "";


    // The default constructor which just sets the configuration data
    public LDAPAuthenticator(HashMap<String, String> configData) {
        this.configData = configData;
    }

    /**
     * Method to set the hashmap containing configuration data
     *
     * @param configData Hashmap containing the configuration data
     */
    public void setConfigData(HashMap<String, String> configData) {
        this.configData = configData;
    }

    /**
     * Method to authenticate the user using a ldap server
     *
     * @param username The user name
     * @param password The password
     * @return boolean indicating whether user authenticated or not
     */
    public boolean authenticateUser(String username, String password) {
        Hashtable authEnv = new Hashtable(11);

        //String base = "ou=People,dc=example,dc=com"; // needs to be read in
        String base = configData.get("base");
        String dn = "uid=" + username + "," + base;
        //String ldapURL = "ldap://ldap.example.com:389"; // needs to be read in
        String ldapURL = configData.get("url");

        authEnv.put(Context.INITIAL_CONTEXT_FACTORY,"com.sun.jndi.ldap.LdapCtxFactory");
        authEnv.put(Context.PROVIDER_URL, ldapURL);
        authEnv.put(Context.SECURITY_AUTHENTICATION, "simple");
        authEnv.put(Context.SECURITY_PRINCIPAL, dn);
        authEnv.put(Context.SECURITY_CREDENTIALS, password);

        try {
            DirContext authContext = new InitialDirContext(authEnv);

            message = "LDAP Authentication Success!";
            System.out.println(message);

            return true;
        } catch (AuthenticationException authEx) {
            message = "Authentication Failed!";
        } catch (NamingException namEx) {
            message = "An Error occurred!\n" + namEx.getExplanation();
            namEx.printStackTrace();
        }

        // print out the error message
        System.out.println(message);

        // something went wrong if we got here, so return false;
        return false;
    }

    /**
     * Method to return the message indicating authentication success or
     * the error message
     * @return The message string
     */
    public String getMessage() {
        return message;
    }
}
