package org.archiviststoolkit.plugin;

import org.archiviststoolkit.ApplicationFrame;
import org.archiviststoolkit.editor.ArchDescriptionFields;
import org.archiviststoolkit.mydomain.DomainEditorFields;
import org.archiviststoolkit.mydomain.DomainObject;
import org.archiviststoolkit.swing.InfiniteProgressPanel;
import org.java.plugin.Plugin;

import javax.swing.*;
import java.awt.*;
import java.util.HashMap;

/**
 * Archivists' Toolkit(TM) Copyright � 2005-2010 Regents of the University of California, New York University, & Five Colleges, Inc.
 * All rights reserved.
 * <p/>
 * This software is free. You can redistribute it and / or modify it under the terms of the Educational Community License (ECL)
 * version 1.0 (http://www.opensource.org/licenses/ecl1.php)
 * <p/>
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the ECL license for more details about permissions and limitations.
 * <p/>
 * <p/>
 * Archivists' Toolkit(TM)
 * http://www.archiviststoolkit.org
 * info@archiviststoolkit.org
 * <p/>
 * Created by IntelliJ IDEA.
 *
 * This is a simple plugin that provides sample code for implementing a plugin
 * that can handle authentication
 *
 * @author: Nathan Stevens
 * Date: Dec 8, 2010
 * Time: 3:31:41 PM
 */
public class LoginPlugin extends Plugin implements ATPlugin {
    public static final String CONFIG_DATA_NAME = "Config Data";
    public static final String PLUGIN_NAME = "Login Plugin";
    protected ApplicationFrame mainFrame;

    /**
     * Get the category this plugin belongs to
     *
     * @return The category of this plugin
     */
    public String getCategory() {
        return ATPlugin.DEFAULT_CATEGORY + " " +
               ATPlugin.AUTHENTICATION_CATEGORY;
    }

    /**
     * Get the name of the plugin
     *
     * @return The name of this plugin
     */
    public String getName() {
        return "Demo LDAP Authenticator";
    }

    // Method to set the AT main frame
    public void setApplicationFrame(ApplicationFrame mainFrame) {
        this.mainFrame = mainFrame;
    }

    // Method to display the configuration dialog
    public void showPlugin() {
        if(mainFrame != null && mainFrame.getCurrentUserAccessClass() >= 4) {
            LoginPluginConfigDialog configDialog = new LoginPluginConfigDialog(mainFrame);
            configDialog.setModal(true);
            configDialog.pack();
            configDialog.setVisible(true);
        }
    }

    // Method to specify a specific task passing in parameters
    public boolean doTask(String task, String[] taskParams) {
        // try loading the configuration data. If no configuration data
        // then return false
        HashMap<String,String> configData = LoginPluginUtil.loadConfigData();

        if(configData != null) {
            LDAPAuthenticator authenticator = new LDAPAuthenticator(configData);
            return authenticator.authenticateUser(taskParams[0], taskParams[1]);
        } else {
            return false;
        }
    }


    /** Methods below this point need to be implemented by are note used **/


    // method to display a plugin that needs a parent frame
    public void showPlugin(Frame owner) { }

    // method to display a plugin that needs a parent dialog
    public void showPlugin(Dialog owner) { }

    // Method to return any embedded plugins. This can be any thing
    public HashMap getEmbeddedPanels() {
        return null;
    }

    // Method to return hashmap containing list of RDE plugins
    public HashMap getRapidDataEntryPlugins() {
        return null;
    }

    // Method to set the editor field. This is not used here
    public void setEditorField(ArchDescriptionFields editorField) {  }

    // Method to set the editor field. This is not used here
    public void setEditorField(DomainEditorFields editorField) {  }

    /**
     * Method to set the domain object for this plugin
     */
    public void setModel(DomainObject domainObject, InfiniteProgressPanel monitor) { }

    /**
     * Method to get the table from which the record was selected
     * @param callingTable The table containing the record
     */
    public void setCallingTable(JTable callingTable) { }

    /**
     * Method to set the selected row of the calling table
     * @param selectedRow
     */
    public void setSelectedRow(int selectedRow) { }

    /**
     * Method to set the current record number along with the total number of records
     * @param recordNumber The current record number
     * @param totalRecords The total number of records
     */
    public void setRecordPositionText(int recordNumber, int totalRecords) { }

    // Method to do a specific task in the plugin
    public void doTask(String task) { }

    // Method to get the list of specific task the plugin can perform
    public String[] getTaskList() {
        return null;
    }

    // Method to return the editor type for this plugin
    public String getEditorType() {
        return null;
    }

    // code that is executed when plugin starts. not used here
    protected void doStart()  { }

    // code that is executed after plugin stops. not used here
    protected void doStop()  { }    
}
