/*
 * Created by JFormDesigner on Thu Dec 09 12:34:01 EST 2010
 */

package org.archiviststoolkit.plugin;

import java.awt.*;
import java.awt.event.*;
import java.util.HashMap;
import javax.swing.*;
import javax.swing.border.*;

/**
 * @author Nathan Stevens
 */
public class LoginPluginConfigDialog extends JDialog {
    private HashMap<String, String> configData = new HashMap<String, String>();

    public LoginPluginConfigDialog(Frame owner) {
        super(owner);
        initComponents();
        loadConfigData();
    }


    public LoginPluginConfigDialog(Dialog owner) {
        super(owner);
        initComponents();
        loadConfigData();
    }

    // Method to load configuration data
    private void loadConfigData() {
        configData = LoginPluginUtil.loadConfigData();

        if(configData != null) {
           baseTextField.setText(configData.get("base"));
           ldapURLTextField.setText(configData.get("url"));
        } else {
            configData = new HashMap<String, String>();
        }
    }

    // Method to save the configuration data
    private void saveConfigData() {
        try {
            configData.put("base", baseTextField.getText().trim());
            configData.put("url", ldapURLTextField.getText().trim());
            LoginPluginUtil.saveConfigData(configData);
        } catch(Exception e) {
            JOptionPane.showMessageDialog(this,
							"Unable to save login configuration to the database",
							"Save Configuration Error",
							JOptionPane.WARNING_MESSAGE);
            e.printStackTrace();
        }
    }

    private void cancelButtonActionPerformed() {
        setVisible(false);
        dispose();
    }

    private void okButtonActionPerformed() {
        saveConfigData();
        dispose();
        setVisible(false);
    }

    // Method that is called when the test button is pressed. It just tries to
    // connect to ldap server and authenticate user
    private void testButtonActionPerformed() {
        // clear the text area ...
        messageTextArea.setText("Attempting to Connect ...");

        // load the new configuration data
        configData.put("base", baseTextField.getText().trim());
        configData.put("url", ldapURLTextField.getText().trim());

        // get the username and password now
        String username = usernameTextField.getText().trim();
        String password = new String(passwordField.getPassword());

        // try to authenticate using the passed in information
        LDAPAuthenticator authenticator = new LDAPAuthenticator(configData);
        authenticator.authenticateUser(username, password);

        // display the message that was generated while attempting to authenticate
        messageTextArea.setText(authenticator.getMessage());
    }

    private void initComponents() {
        // JFormDesigner - Component initialization - DO NOT MODIFY  //GEN-BEGIN:initComponents
        // Generated using JFormDesigner non-commercial license
        dialogPane = new JPanel();
        contentPanel = new JPanel();
        label2 = new JLabel();
        baseTextField = new JTextField();
        label3 = new JLabel();
        ldapURLTextField = new JTextField();
        separator1 = new JSeparator();
        panel1 = new JPanel();
        label4 = new JLabel();
        usernameTextField = new JTextField();
        label5 = new JLabel();
        passwordField = new JPasswordField();
        label1 = new JLabel();
        scrollPane1 = new JScrollPane();
        messageTextArea = new JTextArea();
        buttonBar = new JPanel();
        testButton = new JButton();
        okButton = new JButton();
        cancelButton = new JButton();

        //======== this ========
        setTitle("LDAP Connection Configuration");
        Container contentPane = getContentPane();
        contentPane.setLayout(new BorderLayout());

        //======== dialogPane ========
        {
            dialogPane.setBorder(new EmptyBorder(4, 4, 4, 4));
            dialogPane.setLayout(new BorderLayout());

            //======== contentPanel ========
            {
                contentPanel.setLayout(new GridBagLayout());
                ((GridBagLayout)contentPanel.getLayout()).columnWidths = new int[] {0, 0, 0};
                ((GridBagLayout)contentPanel.getLayout()).rowHeights = new int[] {0, 0, 0, 0, 0, 0, 0};
                ((GridBagLayout)contentPanel.getLayout()).columnWeights = new double[] {0.0, 1.0, 1.0E-4};
                ((GridBagLayout)contentPanel.getLayout()).rowWeights = new double[] {1.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0E-4};

                //---- label2 ----
                label2.setText("Base");
                contentPanel.add(label2, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 2, 2), 0, 0));

                //---- baseTextField ----
                baseTextField.setColumns(30);
                baseTextField.setText("ou=People,dc=example,dc=com");
                contentPanel.add(baseTextField, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 2, 0), 0, 0));

                //---- label3 ----
                label3.setText("Ldap Url");
                contentPanel.add(label3, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 2, 2), 0, 0));

                //---- ldapURLTextField ----
                ldapURLTextField.setColumns(30);
                ldapURLTextField.setText("ldap://ldap.example.com:389");
                contentPanel.add(ldapURLTextField, new GridBagConstraints(1, 1, 1, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 2, 0), 0, 0));
                contentPanel.add(separator1, new GridBagConstraints(0, 2, 2, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 2, 0), 0, 0));

                //======== panel1 ========
                {
                    panel1.setLayout(new GridLayout(1, 4, 1, 1));

                    //---- label4 ----
                    label4.setText("Username");
                    panel1.add(label4);
                    panel1.add(usernameTextField);

                    //---- label5 ----
                    label5.setText("Password");
                    panel1.add(label5);
                    panel1.add(passwordField);
                }
                contentPanel.add(panel1, new GridBagConstraints(0, 3, 2, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 2, 0), 0, 0));

                //---- label1 ----
                label1.setText("Message Console:");
                contentPanel.add(label1, new GridBagConstraints(0, 4, 2, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 2, 0), 0, 0));

                //======== scrollPane1 ========
                {

                    //---- messageTextArea ----
                    messageTextArea.setRows(4);
                    scrollPane1.setViewportView(messageTextArea);
                }
                contentPanel.add(scrollPane1, new GridBagConstraints(0, 5, 2, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 0, 0), 0, 0));
            }
            dialogPane.add(contentPanel, BorderLayout.CENTER);

            //======== buttonBar ========
            {
                buttonBar.setBorder(new EmptyBorder(12, 0, 0, 0));
                buttonBar.setLayout(new GridBagLayout());
                ((GridBagLayout)buttonBar.getLayout()).columnWidths = new int[] {0, 0, 85, 80};
                ((GridBagLayout)buttonBar.getLayout()).columnWeights = new double[] {0.0, 1.0, 0.0, 0.0};

                //---- testButton ----
                testButton.setText("Test");
                testButton.addActionListener(new ActionListener() {
                    public void actionPerformed(ActionEvent e) {
                        testButtonActionPerformed();
                    }
                });
                buttonBar.add(testButton, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 0, 5), 0, 0));

                //---- okButton ----
                okButton.setText("OK");
                okButton.addActionListener(new ActionListener() {
                    public void actionPerformed(ActionEvent e) {
                        okButtonActionPerformed();
                    }
                });
                buttonBar.add(okButton, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 0, 5), 0, 0));

                //---- cancelButton ----
                cancelButton.setText("Cancel");
                cancelButton.addActionListener(new ActionListener() {
                    public void actionPerformed(ActionEvent e) {
                        cancelButtonActionPerformed();
                    }
                });
                buttonBar.add(cancelButton, new GridBagConstraints(3, 0, 1, 1, 0.0, 0.0,
                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
                    new Insets(0, 0, 0, 0), 0, 0));
            }
            dialogPane.add(buttonBar, BorderLayout.SOUTH);
        }
        contentPane.add(dialogPane, BorderLayout.CENTER);
        pack();
        setLocationRelativeTo(getOwner());
        // JFormDesigner - End of component initialization  //GEN-END:initComponents
    }

    // JFormDesigner - Variables declaration - DO NOT MODIFY  //GEN-BEGIN:variables
    // Generated using JFormDesigner non-commercial license
    private JPanel dialogPane;
    private JPanel contentPanel;
    private JLabel label2;
    private JTextField baseTextField;
    private JLabel label3;
    private JTextField ldapURLTextField;
    private JSeparator separator1;
    private JPanel panel1;
    private JLabel label4;
    private JTextField usernameTextField;
    private JLabel label5;
    private JPasswordField passwordField;
    private JLabel label1;
    private JScrollPane scrollPane1;
    private JTextArea messageTextArea;
    private JPanel buttonBar;
    private JButton testButton;
    private JButton okButton;
    private JButton cancelButton;
    // JFormDesigner - End of variables declaration  //GEN-END:variables
}
