package org.archiviststoolkit.plugin;

import com.thoughtworks.xstream.XStream;
import org.archiviststoolkit.model.ATPluginData;
import org.archiviststoolkit.mydomain.DomainAccessObject;
import org.archiviststoolkit.mydomain.DomainAccessObjectFactory;

import java.util.Collection;
import java.util.HashMap;

/**
 * Archivists' Toolkit(TM) Copyright  2005-2010 Regents of the University of California, New York University, & Five Colleges, Inc.
 * All rights reserved.
 * <p/>
 * This software is free. You can redistribute it and / or modify it under the terms of the Educational Community License (ECL)
 * version 1.0 (http://www.opensource.org/licenses/ecl1.php)
 * <p/>
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the ECL license for more details about permissions and limitations.
 * <p/>
 * <p/>
 * Archivists' Toolkit(TM)
 * http://www.archiviststoolkit.org
 * info@archiviststoolkit.org
 * <p/>
 * Created by IntelliJ IDEA.
 *
 * Utility class for the LoginPlugin whic loads and save configuation data to the
 * database
 *
 * @author: Nathan Stevens
 * Date: Dec 9, 2010
 * Time: 11:08:19 AM
 */
public class LoginPluginUtil {
    //Method to load the configuration data
    public static HashMap loadConfigData() {
        try {

            ATPluginData pluginData = getPluginData(LoginPlugin.CONFIG_DATA_NAME);
            if(pluginData != null) {
                HashMap<String,String> configData = (HashMap<String, String>)getObjectFromPluginData(pluginData);
                return configData;
            } else {
                return null;
            }
        } catch(Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    // Method to save the configuration data to the database
    public static void saveConfigData(HashMap<String,String> configData) throws Exception {
        String dataName = LoginPlugin.CONFIG_DATA_NAME;
        ATPluginData pluginData = getPluginData(dataName);

        // use Xstream to convert the java object to an xml string
        XStream xstream = new XStream();
        String dataString = xstream.toXML(configData);

        // see If there is an configuration data already saved. If any is found then
        // update it.
        if(pluginData == null) {
            pluginData = new ATPluginData(LoginPlugin.PLUGIN_NAME, true,
                    1, dataName, LoginPlugin.CONFIG_DATA_NAME, dataString);
        } else {
            pluginData.setDataString(dataString);
        }

        // save using temp session
        try {
            Class clazz = pluginData.getClass();

            DomainAccessObject access =
                    DomainAccessObjectFactory.getInstance().getDomainAccessObject(clazz);
            //access.getLongSession();
            access.update(pluginData);
        } catch(Exception e) {
            e.printStackTrace();
            throw e;
        }
    }

    // Method to get object from plugin data
    public static Object getObjectFromPluginData(ATPluginData pluginData) {
        XStream xstream = new XStream();
        xstream.setClassLoader(LoginPluginUtil.class.getClassLoader());
        return xstream.fromXML(pluginData.getDataString());
    }

    // Method to get the login plugin data
    public static ATPluginData getPluginData(String dataName) throws Exception {
        try {
            DomainAccessObject access =
                    DomainAccessObjectFactory.getInstance().getDomainAccessObject(ATPluginData.class);

            ATPluginData pluginData = new ATPluginData();
            pluginData.setPluginName(LoginPlugin.PLUGIN_NAME);
            pluginData.setDataName(dataName);

            Collection collection = access.findByExample(pluginData);

            // get the plugin data object returned from the database only return the first one
            if(collection != null && collection.size() > 0) {
                Object[] dataFound = collection.toArray();
                pluginData = (ATPluginData)dataFound[0];
                return pluginData;
            } else {
                return null;
            }
        } catch(Exception e) {
            e.printStackTrace();
            throw new Exception("Error Getting Plugin Data from Database ...");
        }
    }
}
